options papersize=(10in 7.5in) orientation=landscape;
%let odson=ods graphics on / width=800px height=600px imagefmt=png imagemap=on imagename="vBarPlot" border=off; ;
%let odsoff=ods graphics on / reset=all imagename="MyResetplot";
%let odsppon=ods powerpoint file="/folders/myfolders/pops2.pptx" style=PowerPointLight;
/* proc report section here...*/
%let odsppoff=ods powerpoint close;
%let xal="Age" values=(15 to 95 by 5) grid;
libname mf "/folders/myfolders/tables";
libname pus2012 "/folders/myfolders/censusdata/2012";
options fmtsearch=(pus.formats) symbolgen;

/** Import the CSV file.  **/
proc import datafile="/folders/myfolders/lifetable.csv"
		    out=mf.lt
		    dbms=csv
		    replace;
run;
/** Print the results. **/
title 'lifetables 2010 (from the Social Security Administration)';
proc print data=mf.lt; run;

%let N=1000;
data mf.genPop(keep=x);
call streaminit(3214);
array p[3] _temporary_ (0.5 0.2 0.3);
do i = 1 to &N;
  x = rand("Table", of p[*]);
  output;
end;
run;
proc freq data=mf.genPop;
  tables x / out=mf.od;
run;
data mf.od;
  set mf.od;
  pb=Percent/100;
run;
&odson;
proc sgplot data=mf.od;
  vbar x / response=pb CATEGORYORDER= RESPDESC;
  title "distribution";
  xaxis label="X";
  yaxis label="probability";
  footnote 'samples generated by a function';
run;
&odsoff;
quit;

libname pus2012 "/folders/myfolders/censusdata/2012";
data mf.freqoutCV;
  set pus2012.freqoutcv;
  pb = Percent/100;
run;
&odson;
proc sgplot data=mf.freqoutCV;
  title "Current Veterans";
  series x=agep y=pb ;
  xaxis label=&xal;
  yaxis label="Probability" max=0.04;
  footnote 'from the 2012 American Community Survey';
run;
&odsoff;

proc transpose data=mf.freqoutCV out=mf.vetagepdf_trans(drop=_LABEL_ rename=(_NAME_=var)) prefix=x;
var agep percent pb;
proc sql;
  select * from mf.vetagepdf_trans;
  select count(*) from mf.vetagepdf_trans;
quit;

%let N=	2200000;
data mf.CurrentGen(keep=x);
call streaminit(3215);
array p[79] _temporary_ (0.000057 	0.000226 	0.000585 	0.001495 	0.001964 	0.002686 	0.003524 	0.00425 	0.005592 	0.006175 	0.006553 	0.0073 	0.007474 	0.007776 	0.007957 	0.007778 	0.006833 	0.006979 	0.007792 	0.007536 	0.007653 	0.00805 	0.008835 	0.010932 	0.011336 	0.012419 	0.012083 	0.011974 	0.013082 	0.012756 	0.014264 	0.015287 	0.015392 	0.016714 	0.015429 	0.014817 	0.015652 	0.016245 	0.016967 	0.016689 	0.016341 	0.015962 	0.017712 	0.019692 	0.021515 	0.025923 	0.030602 	0.033758 	0.037967 	0.02707 	0.023553 	0.023029 	0.023335 	0.020031 	0.018102 	0.017247 	0.018098 	0.017139 	0.016526 	0.016478 	0.016383 	0.017033 	0.017713 	0.017295 	0.01569 	0.014107 	0.012599 	0.012683 	0.011943 	0.011209 	0.009764 	0.008518 	0.006331 	0.003533 	0.000909 	0.002626 	0.008474 	0.0057 	0.000299);
do i = 1 to &N;
  x1 = rand("Table", of p[*]);
  x=x1+16;
  output;
end;
run;
proc freq data=mf.CurrentGen;
  tables x / out=mf.od1;
run;
data mf.od1;
  set mf.od1;
  pb = Percent/100;
run;
proc sort data=mf.od1;
by x;
quit;
/* %let odson=ods graphics on / width=11.5in imagefmt=png imagemap=on imagename="vBarPlot" border=off; ; */
/* %let odsoff=ods graphics on / reset=all imagename="MyResetplot"; ; */
/* title " "; */
/* &odson; */
/* proc sgplot data=od; */
/*   vbar x / response=pb; */
/*   title "distribution"; */
/*   xaxis label='X'; */
/*   yaxis label='probability'; */
/*   footnote 'samples generated by a function'; */
/* run; */
/* quit; */
/* &odsoff; */
proc sql;
  select * from mf.od1 order by x;
quit;
&odson;
proc sgplot data=mf.od1;
  title "Current Veterans generated";
  series x=x y=pb ;
  xaxis label=&xal;
  yaxis label="Probability";
  footnote 'from the rand("table") function generated data';
run;
&odsoff;

/* New vets */
libname pus2012 "/folders/myfolders/censusdata/2012";
data mf.freqoutNV;
  set pus2012.freqoutnv;
  pb = Percent/100;
run;
&odson;
proc sgplot data=mf.freqoutNV;
  title "New Veterans";
  series x=vetage y=pb ;
  xaxis label=&xal;
  yaxis label="Probability" max=0.08;
  footnote 'from the 2012 American Community Survey';
run;
&odsoff;
proc sql;
  select count(*) from mf.freqoutNV;
quit;
proc transpose data=mf.freqoutNV out=mf.freqoutpdf_trans(drop=_LABEL_ rename=(_NAME_=var)) prefix=x;
var vetage percent pb;
proc sql;
  select * from mf.freqoutpdf_trans;
quit;

%macro gennv(N);
/* %let N=	18000; */
data mf.NewGen(keep=x);
  call streaminit(3214);
  array p[61] _temporary_ (0.001447 	0.00376 	0.009206 	0.019647 	0.030841 	0.042973 	0.057762 	0.068525 	0.071224 	0.072418 	0.074236 	0.074182 	0.07831 	0.061718 	0.048805 	0.040078 	0.035275 	0.026973 	0.020545 	0.015766 	0.012296 	0.010566 	0.009416 	0.009018 	0.00867 	0.008069 	0.007759 	0.008389 	0.008165 	0.007243 	0.007711 	0.006531 	0.006478 	0.005409 	0.004815 	0.004326 	0.003728 	0.00302 	0.002665 	0.002649 	0.001775 	0.001485 	0.001217 	0.001027 	0.000856 	0.000728 	0.000561 	0.000505 	0.000325 	0.000283 	0.000192 	0.00015 	0.000095 	0.000051 	0.000025 	0.000046 	0.000035 	9.934E-6 	2.671E-6 	9.418E-6 	9.512E-6);
  do i = 1 to &N;
    x = rand("Table", of p[*])+16;
    output;
  end;
run;
%mend;
%gennv(18000);

proc freq data=mf.NewGen;
  tables x / out=mf.od2;
run;
data mf.od2;
  set mf.od2;
  pb = Percent/100;
run;
proc sort data=mf.od2;
by x;
quit;
proc sql;
  select * from mf.od2 order by x;
quit;
&odson;
proc sgplot data=mf.od2;
  title "New Veterans generated data";
  series x=x y=pb ;
  xaxis label=&xal;
  yaxis label="Probability";
  footnote 'from the rand("table") function generated data';
run;
&odsoff;
/* data lt.alive2020; */
/* set lt.goldengates2; */
/* inc=2020-ClockYear; */
/* pd=getnol_macro(eage,eage+inc); */
/* if ClockYear > 2020 then */
/*   delete */
/* ; */
/* run */

data mf.currs;
  set mf.currentgen mf.newgen;
  entryyr=2012;
run;
options cmplib=work.ds;

%macro getnol;
%global RC;
%let RC=;
%let inreturned=;
proc sql noprint;
  select mnl into :inret
    from mf.lt where ea = &a ;
  select 1-mnl/&inret into :p
    from mf.lt where ea = &b ;
quit;
%mend getnol;
proc fcmp outlib = work.ds.functions;
function getnol_macro(a, b);
  rc = run_macro('getnol', a, b, p);
  if rc eq 0 then return(p);
    else
  return(.);
endsub;
run; 

%macro cycle(yr);
  data mf.newgen&yr;
    set mf.newgen;
    entryyr=&yr.;
  run;
  data mf.currs;
     set mf.currs mf.newgen&yr. ;
     x = x + 1;
  run; 
  proc sql;
    create table mf.alivescnt&yr as
      select x, entryyr, count(*) as cnt
        from mf.currs
        where entryyr le &yr
        group by x, entryyr;
  quit; 
  data mf.alive&yr.;
    set mf.alivescnt&yr;
    inc=&yr-entryyr;
    pd=getnol_macro(x,x+inc);/*     if entryyr > &yr-1 then delete; */
    newcnt=round(cnt*(1-pd));
  run;
%mend cycle;

%cycle(2013);
%cycle(2014);
%cycle(2015);
%cycle(2016);
%cycle(2017);
%cycle(2018);
%cycle(2019);
%cycle(2020);
%cycle(2021);
%cycle(2022);
%cycle(2023);
%cycle(2024);
%cycle(2025);
%cycle(2026);
%cycle(2027);
%cycle(2028);
%cycle(2029);
%cycle(2030);
%cycle(2031);
%cycle(2032);
%cycle(2033);
%cycle(2034);

/* data lt.alive2020; */
/* set lt.goldengates2; */
/* inc=2020-ClockYear; */
/* pd=getnol_macro(eage,eage+inc); */
/* if ClockYear > 2020 then */
/*   delete */
/* ; */
/* run */

/* proc sql; */
/*   create table mf.alivecnts as */
/*     select x, entryyr, count(*) as cnt */
/*       from mf.alives */
/*       group by x, entryyr; */
/* quit; */

ods _all_ close;
title1;
footnote 'From the American Community Survey 2012 and the Social Security Administrations Period of Life tables 2010';
ods escapechar = "^"; 
ods PowerPoint file="/folders/myfolders/pops4.pptx" style=PowerPointLight layout=titleslide 
    nogtitle nogfootnote;

proc odstext; 
p "Population Distributions of Veterans" / style=presentationtitle; 
p "Projected forward by using SAS University Edition" / 
    style=presentationtitle2; 
run; 

/* ods html close; */
/* ods PowerPoint close; */
/*  */
/* ods PowerPoint file="/folders/myfolders/pops3.pptx" style=PowerPointLight layout=titleslide  */
/*     nogtitle nogfootnote; */
proc sql;
  delete from mf.alivescnt;
quit;

%macro alives(yr);

proc sql noprint;
  select sum(newcnt) into :tot from mf.alive&yr.;
  select sum(newcnt)*10 into :bt from mf.alive&yr;
  create table mf.alive&yr.sums as
  select x as age, sum(newcnt) as cnt, sum(newcnt)/&tot as pb
    from mf.alive&yr
    group by x
    order by x desc;
  create table mf.alive&yr.sums2 as
  select distinct &yr as yr, sum(newcnt) as total
    from mf.alive&yr;
quit;
data mf.alivescnt;
    set mf.alivescnt mf.alive&yr.sums2;
run;
ods PowerPoint image_dpi=300 layout=_null_ ;

proc sgplot data=mf.alive&yr.sums;
  title3 " " ;  
  title4 "population projected to be &bt for &yr" ;
  title5 " " ;  
  series x=age y=pb ;
  xaxis label=&xal;
  yaxis label="Probability" min=0 max=0.04;
  footnote ' ';
run; 
%mend alives;

%alives(2013);
%alives(2014);
%alives(2015);
%alives(2016);
%alives(2017);
%alives(2018);
%alives(2019);
%alives(2020);
%alives(2021);
%alives(2022);
%alives(2023);
%alives(2024);
%alives(2025);
%alives(2026);
%alives(2027);
%alives(2028);
%alives(2029);
%alives(2030);
%alives(2031);
%alives(2032);
%alives(2033);
%alives(2034);
data mf.alivescnt;
  set mf.alivescnt;
  total=total/100000;
run;
proc sgplot data=mf.alivescnt;
  title3 " " ;  
  title4 "Veteran Population trend" ;
  title5 " " ;  
  series x=yr y=total ;
  refline 5 to 20 by 5 / axis=y lineattrs=(pattern=2); 
  xaxis label='Year' values=(2013 to 2035 by 2);
  yaxis label="Veteran Population (millions)" values=(0 to 25 by 5);
  footnote ' ';
run; 

ods _all_ close;

proc sql;
  select entryyr, count(*) as cnt
    from mf.currs
    group by entryyr;
quit;

  



